department

package
v0.0.0-...-7cf6ef0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2018 License: Apache-2.0 Imports: 4 Imported by: 1

Documentation

Overview

Copyright 2018. bolaxy.org authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright 2018. bolaxy.org authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddDepartment

func AddDepartment(department *Pdepartment) reterror.ErrModel

AddDepartment add department

func DelDepartment

func DelDepartment(department *Pdepartment) reterror.ErrModel

DelDepartment delete department

func DepartmentList

func DepartmentList() reterror.ErrModel

DepartmentList get department list

func EditDepartment

func EditDepartment(department *Pdepartment) reterror.ErrModel

EditDepartment edit department

func GetAccountsByDepartment

func GetAccountsByDepartment(depID int, authID int) reterror.ErrModel

GetAccountsByDepartment get accounts by department id or auth id

func SortDep

func SortDep(depID string) reterror.ErrModel

SortDep sort department

Types

type Pdepartment

type Pdepartment struct {
	ID        int    `form:"id"`
	CreatorID int    `form:"creator_id"`
	Name      string `form:"dep_name"`
	AuthID    int    `form:"auth_id"`
	AccountID int    `form:"account_id"`
	DepID     string `form:"dep_id"`
}

Jump to